#
# spec file for package python-ftputil
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15allpythons}
Name:           python-ftputil
Version:        5.1.0
Release:        2.1
Summary:        High-level FTP client library (virtual file system and more) for Python
License:        BSD-3-Clause
URL:            http://ftputil.sschwarzer.net/
Source:         https://files.pythonhosted.org/packages/source/f/ftputil/ftputil-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module freezegun}
# /SECTION
BuildArch:      noarch

%python_subpackages

%description
FTPutil is a high-level FTP client library for the Python programming
language. ftputil implements a virtual file system for accessing FTP
servers, that is, it can generate file-like objects for remote files.
The library supports many functions similar to those in the os,
os.path and shutil modules. ftputil has convenience functions for
conditional uploads and downloads, and handles FTP clients and
servers in different timezones.

%prep
%setup -q -n ftputil-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Requires network
%pytest --ignore test/test_real_ftp.py -k 'not (test_upload or test_servers)'

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/ftputil
%{python_sitelib}/ftputil-%{version}.dist-info

%changelog
* Tue Jun 17 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Run the testsuite.
* Wed Apr 16 2025 Felix Stegmeier <felix.stegmeier@suse.com>
- Update to 5.1.0
  * When the path encoding is specified as UTF-8, send `OPTS UTF8 ON` if
    the server supports it
  * ftputil uses `ftplib.FTP` as default session factory, but explicitly
    sets the path encoding to latin-1 (regardless of the Python
    version). This is the same behavior as in ftputil 4.0.0 or earlier
    if running under Python 3.8 or earlier.
  * If client code uses a custom session factory (i. e. the
    `session_factory` argument of the `FTPHost` constructor), ftputil
    will take the path encoding to use for `bytes` paths from the
    `encoding` attribute of an FTP session from this factory. If there's
    no such attribute, an exception is raised.
* Wed Apr 10 2024 Christian Keil <keil@dfn-cert.de>
- Add Python 3.11 build.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Update summary.
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 3.4
  * Added support for Python 3
  * Dropped support for Python 2.4 and 2.5
  * Newlines and encoding of remote file content
  * Upload and download modes
  * Custom parsers receive lines as unicode strings
- Implement single-spec version
* Fri Sep 23 2011 saschpe@suse.de
- Initial version
